@@ -2,6 +2,9 @@ import os
 import logging
 from pathlib import Path
 from typing import Optional
+from dotenv import load_dotenv
+
+load_dotenv()
 
 
 def get_logger(
